#!/usr/bin/python
"""
Author: Anja Spang
Removes sequences that contain a specific header
"""

#Import modules
##########################################################################################
import sys
import os
import argparse
from Bio import SeqIO
import re



#ARGPARSE
##########################################################################################

parser = argparse.ArgumentParser(description='removes seq with specific header from multifasta file')
parser.add_argument('-a','--input1', metavar='FASTA', required = True, help='multifasta file')
parser.add_argument('-l','--input2', required = True, help='file listing headers to be removed, one header per line')
parser.add_argument('-o','--output', metavar='FASTA', help='multifasta file in which sequences with specific header have been removed', required = True)
parser.add_argument('-r','--output2', metavar='FASTA', help='multifasta file with removed sequences', required = True)
args = parser.parse_args()

if args.input1 is None and not os.path.exists(args.input):
    print("Multifasta file missing!")
    sys.exit(-1)

if args.input2 is None and not os.path.exists(args.char):
    print("Which sequences do you want to remove?")
    sys.exit(-1)



#Global variables
##########################################################################################
infile = args.input1
infile2 = [entry.strip() for entry in open(args.input2).readlines()]
outfile = open(args.output, "w")
outfile2 = open(args.output2, "w")

#print(infile2)


#Function to remove specific headers
##########################################################################################

def remove_seq_with_spec_header(multifasta, header_list):
	count = 0
	for seq_record in SeqIO.parse(multifasta,"fasta"):
		header = str(seq_record.description).strip()
		seq = str(seq_record.seq).strip()

		count2 = 0

		for acc in header_list:
			#print(acc)

			if acc in header:
				print(header)
				count = count + 1
				outfile2.write(">%s\n%s\n" % (header, seq))
				break
			else:
				count2 = count2 + 1

		if count2 == len(header_list):
			outfile.write(">%s\n%s\n" % (header, seq))

	print("%s sequences have been removed" %(count))



#Call main
##########################################################################################

def main():
	remove_seq_with_spec_header(infile, infile2)

if __name__ == "__main__":
	main()




#Close files
##########################################################################################
outfile.close()
outfile2.close()
